starcluster.commands.listpublic

Package starcluster :: Package commands :: Module listpublic |
[hide private]
[frames] | no frames]

# Source Code for Module starcluster.commands.listpublic

     1  #!/usr/bin/env python
     2
     3  from base import CmdBase
     4
     5
     6 -class CmdListPublic(CmdBase):
     7      """
     8      listpublic
     9
    10      List all public StarCluster images on EC2
    11      """
    12      names = ['listpublic', 'lp']
    13
    14 -    def execute(self, args):
    15          self.ec2.list_starcluster_public_images()
    16